summaryrefslogtreecommitdiffstats
path: root/Bugzilla/Template.pm
diff options
context:
space:
mode:
Diffstat (limited to 'Bugzilla/Template.pm')
-rw-r--r--Bugzilla/Template.pm6
1 files changed, 3 insertions, 3 deletions
diff --git a/Bugzilla/Template.pm b/Bugzilla/Template.pm
index 06be9243c..f3e3685f7 100644
--- a/Bugzilla/Template.pm
+++ b/Bugzilla/Template.pm
@@ -249,10 +249,10 @@ sub create {
# Format a time for display (more info in Bugzilla::Util)
time => \&Bugzilla::Util::format_time,
# Simple filter to obscure the '@' in user visible strings
# See bug 120030 for details
- obscure_email => sub {
- my ($var) = @_;
+ html => sub {
+ my ($var) = Template::Filters::html_filter(@_);
$var =~ s/\@/\@/g;
return $var;
},
@@ -249,10 +249,10 @@ sub create {
# Format a time for display (more info in Bugzilla::Util)
time => \&Bugzilla::Util::format_time,
- # Simple filter to obscure the '@' in user visible strings
+ # Override html filter to obscure the '@' in user visible strings
# See bug 120030 for details